@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * Coverage visualization routines.
  *
- * $Id: coverage_vis.c,v 1.120 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: coverage_vis.c,v 1.134 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #include <math.h>
@@ -75,15 +75,6 @@ static const char format2[] =
 
 static void write_image_as_ppm(FILE *f);
 
-#define LENGTH_APPEARANCE_FILE 1024
-#define LENGTH_LINE 128
-static char dynamic_description[LENGTH_APPEARANCE_FILE];
-static char static_description[LENGTH_APPEARANCE_FILE];
-static char temp_scratchfile[LENGTH_STRING_BUFFER];
-
-static void append_file_suffix(char * filename);
-static char * append_string(char * string, const char * add);
-
 #ifndef NO_ZLIB
 /* used only in this file */
 static int gzip_compress2(Bytef *dest, uLongf *destLen,
@@ -96,8 +87,6 @@ static void write_image_to_file_gz(char *name);
 static void * image_compress_scratch = NULL;
 #endif /* NO_ZLIB */
 
-static int coverage_dynamic_disk_initialised(void);
-
 static void set_coverage(int projection, grid *g);
 
 static int reset_map_foreground(const unsigned char * map_pointer,
@@ -125,7 +114,7 @@ static unsigned char colors[60];
 static unsigned char noaccess_colors[60];
 
 /* Color for earth outline and ground track - see enum in coverage_vis.h */
-static unsigned char outline_colors[] = { 0, 0, 0,  /* background */
+static unsigned char outline_colors[] = { 255, 255, 255,  /* background */
 					  0, 0, 0,	 /* earth outline */
 					  0, 255, 0,    /* projected ground track */
 					  255, 0, 255, /* selected ground track */
@@ -144,6 +133,7 @@ static unsigned char * cyl_foreground;
 static unsigned char * sin_foreground;
 static unsigned char * sin_90_foreground;
 static unsigned char * unp_foreground;
+static unsigned char * unp_mask_foreground;
 static unsigned char * sph_foreground;
 static unsigned char * sph_90_foreground;
 
@@ -268,6 +258,11 @@ image_init(grid * g)
   width = g->width;
   image_size = height * width;
 
+  if (image_size <= 0) {
+     error("image size must be greater than zero.");
+     return;
+  }
+
   image = (Tk_PhotoImageBlock *) malloc(sizeof(Tk_PhotoImageBlock));
   image->pixelPtr = (unsigned char *) malloc(image_size * PIXELSIZE *
 					     sizeof(unsigned char *));
@@ -286,6 +281,7 @@ image_init(grid * g)
     sin_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
     sin_90_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
     unp_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
+    unp_mask_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
     sph_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
     sph_90_foreground = (unsigned char *) malloc(sizeof(char) * image_size);
 
@@ -310,6 +306,11 @@ image_init(grid * g)
 	free(unp_foreground);
 	unp_foreground = NULL;
       }
+      made = overlay_bitmap(height, width, unp_mask_foreground, UNPROJECTED_MASK_LARGE_BITMAP_NAME);
+      if (!made) {
+	free(unp_mask_foreground);
+	unp_mask_foreground = NULL;
+      }
       made = overlay_bitmap(height, width, sph_foreground, SPHERICAL_LARGE_BITMAP_NAME);
       if (!made) {
 	free(sph_foreground);
@@ -342,6 +343,11 @@ image_init(grid * g)
 	free(unp_foreground);
 	unp_foreground = NULL;
       }
+      made = overlay_bitmap(height, width, unp_mask_foreground, UNPROJECTED_MASK_BITMAP_NAME);
+      if (!made) {
+	free(unp_mask_foreground);
+	unp_mask_foreground = NULL;
+      }
       made = overlay_bitmap(height, width, sph_foreground, SPHERICAL_BITMAP_NAME);
       if (!made) {
 	free(sph_foreground);
@@ -586,40 +592,9 @@ coverage_output_image(void)
     } else {
       write_image_to_stream();
     }
-  } else {
-    if (geomview_compressed_images) {
-#ifndef NO_ZLIB
-      write_image_to_file_gz(temp_scratchfile);
-#else
-      error("geomview_compressed_images was set wrongly. Not sending image.");
-#endif
-    } else {
-      write_image_to_file(temp_scratchfile);
-    }
-    coverage_send_scratchfile();
   }
 }
 
-static void
-append_file_suffix(char * filename) {
-  char * string;
-
-  string = filename + strlen(filename);
-
-  if (geomview_compressed_images) {
-    strcpy(string,"-savi.ppm.gz");
-  } else {
-    strcpy(string,"-savi.ppm");
-  }
-}
-
-static char *
-append_string(char * string, const char * add)
-{
-  strcpy(string, add);
-  return(string + strlen(add));
-}
-
 int
 coverage_dynamic_initialised(void)
 {
@@ -648,127 +623,7 @@ coverage_dynamic_initialised(void)
     return(TRUE);
   }
 
-  return(coverage_dynamic_disk_initialised());
-}
-
-static int
-coverage_dynamic_disk_initialised(void)
-{
-  char line[LENGTH_LINE];
-  const char name[] = "oogl/earth.oogl";
-  const char fallback_tmpnam[] = "coverage";
-  const char static_name[] = "oogl/Earth.ppm.Z";
-  const char file_separator[] = "/";
-  const char file_start[] = "file \"";
-  const char file_end[] = "\"\n";
-  char *dynamic_description_end, *static_description_end, *string, *path;
-  const char null_char = 0;
-  const char tab_char = 9;
-  const char space_char = 32;
-  const char comment_char = 35; /* # */
-  unsigned int replaced = 0;
-  unsigned int add_static_length = 0;
-  unsigned int add_dynamic_length = 0;
-  unsigned int incr_length;
-  FILE *f, *g;
-
-  if (NULL == (f = fopen(name, "r"))) {
-    fprintf(stderr,"\nSaVi: unable to open texturemap description %s", name);
-    return(FALSE);
-  }
-
-  string = tmpnam(NULL);
-  strcpy(temp_scratchfile, string);
-  append_file_suffix(temp_scratchfile);
-
-  if (NULL == (g = fopen(temp_scratchfile, "wb+"))) {
-    fprintf(stderr,"\nSaVi: couldn't open assigned tempfile %s", temp_scratchfile);
-    path = getenv("HOME");
-    if (!path) {
-      error("couldn't learn home directory $HOME for fallback scratchfile");
-      return(FALSE);
-    }
-    if (strlen(path) > LENGTH_STRING_BUFFER - 16) {
-      error("pathname of home directory $HOME too long to store.");
-      return(FALSE);
-    }
-    string = append_string(temp_scratchfile, path);
-    string = append_string(string, file_separator);
-    string = append_string(string, fallback_tmpnam);
-    append_file_suffix(temp_scratchfile);
-    if (NULL == (g = fopen(temp_scratchfile, "wb+"))) {
-      fprintf(stderr,"\nSaVi: couldn't open fallback tempfile %s", temp_scratchfile);
-      return(FALSE);
-    }
-  }
-
-  fclose(g);
-
-  fprintf(stderr,"\nSaVi: temporary texturemap scratchfile is %s",
-	  temp_scratchfile);
-
-  dynamic_description_end = dynamic_description;
-  static_description_end = static_description;
-
-  while (fgets(line,100,f) != NULL) {
-    string = line;
-    while ((*string == space_char) || (*string == tab_char)) {
-      /* skip leading whitespace */
-      string++;
-    }
-    if ((*string == comment_char) || (*string == null_char)) {
-      /* skip comments and empty lines */
-      continue;
-    }
-    if (strstr(string,"Earth.ppm.Z")) {
-      /* replace with our file line */
-      incr_length = strlen(file_start) + strlen(temp_scratchfile) +
-	            strlen(file_end);
-      add_dynamic_length += incr_length;
-      path=getenv("SAVI");
-      incr_length = strlen(file_start) + strlen(path) + strlen(file_separator) +
-	            strlen(static_name) + strlen(file_end);
-      add_static_length += incr_length;
-      if ((add_dynamic_length > LENGTH_APPEARANCE_FILE) ||
-	  (add_static_length > LENGTH_APPEARANCE_FILE)) {
-	fprintf(stderr, "\nSaVi: tempfile pathname %s is too long to cache.",
-		temp_scratchfile);
-	return(FALSE);
-      }
-      dynamic_description_end = append_string(dynamic_description_end, file_start);
-      dynamic_description_end = append_string(dynamic_description_end, temp_scratchfile);
-      dynamic_description_end = append_string(dynamic_description_end, file_end);
-      static_description_end = append_string(static_description_end, file_start);
-      static_description_end = append_string(static_description_end, path);
-      static_description_end = append_string(static_description_end, file_separator);
-      static_description_end = append_string(static_description_end, static_name);
-      static_description_end = append_string(static_description_end, file_end);
-      replaced++;
-      continue;
-    }
-
-    incr_length = strlen(string);
-    add_dynamic_length += incr_length;
-    add_static_length += incr_length;
-
-    if ((add_static_length > LENGTH_APPEARANCE_FILE) ||
-	(add_dynamic_length > LENGTH_APPEARANCE_FILE)) {
-      fprintf(stderr, "\nSaVi: Earth appearance in %s is too long to cache.",
-	      name);
-      return(FALSE);
-    }
-
-    dynamic_description_end = append_string(dynamic_description_end, string);
-    static_description_end = append_string(static_description_end, string);
-  }
-
-  if (!replaced) {
-    fprintf(stderr, "\nSaVi: did not find file \"Earth.ppm.Z\" in %s to replace with temp file location.", name);
-  } else if (replaced > 1) {
-    fprintf(stderr, "\nSaVi: found multiple instances of file \"Earth.ppm.Z\" in %s. Problems?", name);
-  }
-
-  return(TRUE);
+  return;
 }
 
 void
@@ -779,10 +634,6 @@ coverage_dynamic_cleanup(void)
 #ifndef NO_ZLIB
       free(image_compress_scratch);
 #endif
-    } else {
-      remove(temp_scratchfile);
-      fprintf(stderr, "\nSaVi: cleaned up temporary scratchfile %s",
-	      temp_scratchfile);
     }
   }
 }
@@ -1007,6 +858,10 @@ new_foreground(int projection, grid * g, unsigned int force)
     Longitude_Center_Line = LONGITUDE_CENTER_LINE;
     coverage_bitmap_drawn = reset_map_foreground(unp_foreground, image_size);
     break;
+  case UNPROJECTED_MASK:
+    Longitude_Center_Line = LONGITUDE_CENTER_LINE;
+    coverage_bitmap_drawn = reset_map_foreground(unp_mask_foreground, image_size);
+    break;
   case SINUSOIDAL:
     Longitude_Center_Line = LONGITUDE_CENTER_LINE;
     coverage_bitmap_drawn = reset_map_foreground(sin_foreground, image_size);
@@ -1040,7 +895,7 @@ new_foreground(int projection, grid * g, unsigned int force)
 void
 grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
 {
-  int drawWidth, middleWidth, projection_supported;
+  int drawWidth, middleWidth, projection_supported, skip_map;
   unsigned int w, h, i, j, offset, ci;
   unsigned int data_value, map_threshold, send_coverage;
   unsigned int sinu_surround = FALSE;
@@ -1066,7 +921,7 @@ grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
   }
 
   projection_supported = (projection == CYLINDRICAL) ||
-                         ((projection == UNPROJECTED) && geomview_stream_textures);
+    (((projection == UNPROJECTED)||(projection == UNPROJECTED_MASK)) && geomview_stream_textures);
 
   send_coverage = geomview_flag && geomview_dynamic_texture_flag &&
                   texture_flag && projection_supported &&
@@ -1078,11 +933,15 @@ grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
     * map outline. For 0/1, could have used || instead of MAX,
     * but MAX is clearer in intent.
     */
-  map_threshold = MAX((send_coverage && !geomview_texture_with_map), !map_flag);
 
-  fill0 = outline_colors[0];
-  fill1 = outline_colors[1];
-  fill2 = outline_colors[2];
+  skip_map = !map_flag || (projection == UNPROJECTED_MASK);
+  
+  map_threshold = MAX((send_coverage && !geomview_texture_with_map), skip_map);
+
+  /* set to match Earth outline */
+  fill0 = outline_colors[3];
+  fill1 = outline_colors[4];
+  fill2 = outline_colors[5];
 
   h = g->height;
   w = g->width;
@@ -1182,13 +1041,28 @@ grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
 
       if (!fgOnly) {
 	data_value = g->data[offset + j];
-	if (data_value || !(no_access_flag || sun_flag)) {
-	  ci = MIN(data_value, NUM_COLORS);
-	  c = colors + PIXELSIZE * ci;
+
+	if (projection == UNPROJECTED_MASK) {
+	  ci = MIN(data_value + 1, NUM_COLORS);
+	  if (*(f-1) == 0) {
+              c = noaccess_colors + PIXELSIZE * ci;
+	      if (!no_access_flag && (ci == 1)) {
+	          c = outline_colors;
+	      }
+
+          } else {
+            c = colors + PIXELSIZE * ci;
+          }
 	} else {
-	  ci = MIN(g->noaccess[offset + j], NUM_COLORS);
-	  c = noaccess_colors + PIXELSIZE * ci;
+	  if (data_value || !(no_access_flag || sun_flag)) {
+	    ci = MIN(data_value, NUM_COLORS);
+	    c = colors + PIXELSIZE * ci;
+	  } else {
+	    ci = MIN(g->noaccess[offset + j], NUM_COLORS);
+	    c = noaccess_colors + PIXELSIZE * ci;
+	  }
 	}
+
 	p[0] = c[0];
 	p[1] = c[1];
 	p[2] = c[2];
@@ -1200,12 +1074,20 @@ grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
     coverage_output_image();
   }
 
-  if (!map_threshold || !map_flag) {
-    /* map outline is already drawn; no need to fill in for coverage window. */
+  if (projection == UNPROJECTED_MASK) {
+    if (map_flag) {
+      f = unp_foreground;
+    } else {
+      f = foreground;
+      return; /* do not draw continents mask */
+    }
+  } else if (!map_flag) {
+    /* map outline is not needed. */
     return;
+  } else {
+    f = foreground;
   }
-
-  f = foreground;
+  
   p = image->pixelPtr;
 
   /* map outline is 1 - cache colors for that from array */
@@ -1225,18 +1107,6 @@ grid_and_foreground_to_image(int projection, grid * g, int fgOnly)
   }
 }
 
-void
-coverage_send_static_file(void)
-{
-  fprintf(gv_out, "(read geometry { define earth_h {\n %s \n} } )", static_description);
-}
-
-void
-coverage_send_scratchfile(void)
-{
-  fprintf(gv_out, "(read geometry { define earth_h {\n %s \n} } )", dynamic_description);
-}
-
 /*
  * tracks_to_foreground - place dot on the foreground map which corresponds
  * to the subsatellite point (nadir).  Do this for every satellite
@@ -1326,6 +1196,7 @@ latlon_to_grid_index(int grid_index[2], LatLon * pl, int projection, grid * g)
 
   switch (projection) {
   case UNPROJECTED:
+  case UNPROJECTED_MASK:
     project_latlon_unprojected(proj, &l);
     break;
   case SINUSOIDAL:
