@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * fisheye.c
  *
- * $Id: fisheye.c,v 1.52 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: fisheye.c,v 1.60 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #include <math.h>
@@ -367,15 +367,16 @@ fisheye_display(const Satellite_list SL, unsigned int force,
 
   /* plot satellite positions */
   {
-    CartesianCoordinates s;
+    CartesianCoordinates ccs;
     double sky[2];
     double t = current_time();
     double interval_time;
     Satellite_list sl = SL;
 
     unsigned int sats_visible, sats_above_mask;
-    int r, d, x, y, x_start, y_start, x_end, y_end;
+    int a, d, n, r, x, y, x_start, y_start, x_end, y_end;
     int adjust = 2;
+    int mirror = -1;
 
     sprintf(cmd,"fisheye(resize)");
     test = tcl_script(cmd);
@@ -405,6 +406,41 @@ fisheye_display(const Satellite_list SL, unsigned int force,
       sprintf(attributes, "-anchor nw -fill blue");
     }
 
+    /* display equatorial ring markers, if turned on. Unmoving, time 0. */
+    if (plane_flag) {
+      sprintf(plotStr, "purple");
+      for (n = 0; n < EQUATORIAL_MARKERS; n++) {
+      
+        oe_time_to_geocentric(&ccs, 0, &(marker[n]->oe), pcb);
+  
+        if (sat_to_fisheye(&ccs, lat, lon, pcb, 0, sky)) {
+	  if (fisheye_reverse_view_flag) {
+	    sky[0] = -sky[0];
+	  }
+	  
+          x = (int) (offset + r * sky[0]);
+	  y = (int) (offset - r * sky[1]); /* North is top of canvas */
+
+	  /* Draw parallels in dark gray. Plain gray is too light on a Mac. */
+	  if (n > 359) {
+	    sprintf(plotStr, "darkgray");
+	    if (n > 719) {
+	      mirror = -mirror;
+	    }
+	  }
+	  
+	  sprintf(cmd, "%s create line %i %i %i %i -fill %s -tags equator",
+                    fisheye_widget, x, y, x, y+mirror, plotStr);
+	  test = tcl_script(cmd);
+        }
+      }
+    }
+
+    if (debug && !test) {
+      error("Problem telling Tk to draw equator markers.");
+    }
+    
+    /* display satellites */
     while (sl) {
 
       if (!sl->s->can_display_satellite) {
@@ -412,9 +448,11 @@ fisheye_display(const Satellite_list SL, unsigned int force,
 	continue;
       }
 
-      oe_time_to_geocentric(&s, t, &(sl->s->oe), pcb);
-      if (sat_to_fisheye(&s, lat, lon, pcb, t, sky)) {
-	sats_visible++;
+      oe_time_to_geocentric(&ccs, t, &(sl->s->oe), pcb);
+      if (sat_to_fisheye(&ccs, lat, lon, pcb, t, sky)) {
+	
+        sats_visible++;
+	
 	if ((sky[0] * sky[0] + sky[1] * sky[1]) <
 	    (coverage_pct * coverage_pct)) {
 	  if (sl->s->gs_into_view == 0) {
@@ -436,9 +474,16 @@ fisheye_display(const Satellite_list SL, unsigned int force,
 	if (fisheye_reverse_view_flag) {
 	  sky[0] = -sky[0];
 	}
+
 	not_visible_to_terminal = ((coverage_type == MASK_ELEVATION) &&
 	                          (!sl->s->gs_into_view)) ||
 	                          !sl->s->can_display_coverage;
+	a = sl->s->x_S.r - pcb->radius;
+	if (a <= min_transmit_altitude) {
+	  not_visible_to_terminal = TRUE;
+	}
+
+
 	if (not_visible_to_terminal || (coverage_type != MASK_ELEVATION)) {
 	  if (fisheye_names_flag) {
 	    if (fisheye_numbers_flag) {
@@ -520,9 +565,11 @@ fisheye_display(const Satellite_list SL, unsigned int force,
 	sprintf(cmd, "%s create line %i %i %i %i -fill %s -tags crosses",
                 fisheye_widget, x_start, y, x_end, y, plotStr);
 	test = test && tcl_script(cmd);
+	
 	if (debug && !test) {
-	  error("Problem telling Tk to draw fisheye canvas crosses.");
+	  error("Problem telling Tk to draw on fisheye.");
 	}
+	
       } else {
 	sl->s->gs_into_view = 0;
 	/*
