@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2012 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * Satellite.h
  *
- * $Id: Satellite.h,v 1.15 2012/01/01 02:48:41 lloydwood Exp $
+ * $Id: Satellite.h,v 1.20 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #ifndef _SATELLITE_H_
@@ -36,7 +36,6 @@
 #define SATELLITE_NAME_LENGTH 25
 
 typedef struct satellite {
-  int id;                                /* identifier of satellite     */
   OrbitalElements oe;                    /* classical orbital elements  */
   OrbitalElements oe_t;                  /* orbital elements at time t  */
   CartesianCoordinates x_C;              /* position in geocentric      */
@@ -44,13 +43,14 @@ typedef struct satellite {
   double t;                              /* time                        */
   double period;                         /* classical period            */
   double transform[4][4];                /* transform for use in gv     */
-  int tag;                               /* used for marking satellites */
   float gs_into_view;                    /* time sat into view on ground*/
   float gs_last_into_view;		 /* previous encounter time     */
   float gs_last_pass;			 /* time sat last pass on ground*/
   unsigned int can_display_satellite:1;  /*   satellite display flag    */
   unsigned int can_display_orbit:1;      /*   orbit display flag        */
   unsigned int can_display_coverage:1;   /*   coverage display flag     */
+  int tag;                               /* used for marking satellites */
+  int id;                                /* identifier of satellite     */
   char name[SATELLITE_NAME_LENGTH];      /*      name identifier        */
 } *Satellite;
 
@@ -63,6 +63,12 @@ typedef struct satellite_list {
   struct satellite_list *next;
 } *Satellite_list;
 
+/*
+ * create array of 'marker' static satellites for equatorial ring
+ */
+#define EQUATORIAL_MARKERS 1080
+Satellite marker[EQUATORIAL_MARKERS];
+
 /*
  * define the constellation struct
  *
