@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * sats.c
  *
- * $Id: sats.c,v 1.56 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: sats.c,v 1.60 2016/01/09 04:21:17 lloydwood Exp $
  */
 #include <stdlib.h>
 #include <string.h>
@@ -49,6 +49,8 @@
 
 unsigned int geomview_flag = FALSE;
 
+static int current_marker = 0;
+
 static double direction; /* 1.0 = FORWARDS, -1.0 = BACKWARDS */
 /*
  * Central body parameter - global from the parameters panel.  It should
@@ -764,6 +766,50 @@ sats_copy_cmd(int argc, char *argv[])
   return result;
 }
 
+/*
+ * sats_load_marker_cmd
+ */
+char *
+sats_load_marker_cmd(int argc, char *argv[])
+{
+
+  double a = atof(argv[2]);
+  double Omega = atof(argv[3]);
+  double omega = atof(argv[4]);
+  double T = atof(argv[5]);
+  char* name = argv[6];
+
+  Satellite s;
+  int n;
+  static char result[20];
+
+  OrbitalElements oe;
+
+  oe.a = a;
+  oe.e = 0;
+  oe.i = 90 * DEG_TO_RAD; /* N/S for drawing vertical lines */
+  oe.Omega = Omega * DEG_TO_RAD;
+  oe.omega = omega * DEG_TO_RAD;
+  oe.T = T;
+
+  if (current_marker >= EQUATORIAL_MARKERS) {
+    current_marker = 0;
+    if (debug) {
+      error("marker creation wrapped round array - redrawing?");
+    }
+  }
+  
+  marker[current_marker] = satellite_create(0, &oe, constellation.pcb);
+  if (name && !satellite_name(marker[current_marker], name)) {
+    error ("problem naming marker.");
+  }
+  satellite_compute_position(marker[current_marker], 0, constellation.pcb);
+
+  current_marker++;
+  
+  return result;
+}
+
 /*
  * sats_load_cmd
  *
