@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2013 by Lloyd Wood.
+ *  Also Copyright (c) 2016 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * tcl_utils.c
  *
- * $Id: tcl_utils.c,v 1.33 2013/05/05 05:19:25 lloydwood Exp $
+ * $Id: tcl_utils.c,v 1.40 2016/01/09 04:21:17 lloydwood Exp $
  */
 
 #include "constants.h"
@@ -161,6 +161,9 @@ tcl_app_init()
   static char var57[] = "DIV(19)";
   static char var58[] = "DEC(19)";
   static char var59[] = "buttons_menu";
+  static char var60[] = "min_transmit_altitude";
+  static char var61[] = "parallels_angle";
+  static char var62[] = "equatorial_exclusion_angle";
 
   unsigned int test;
 
@@ -237,6 +240,9 @@ tcl_app_init()
   Tcl_LinkVar(interp, var57, (char *) &DIV19, TCL_LINK_INT);
   Tcl_LinkVar(interp, var58, (char *) &DEC19, TCL_LINK_INT);
   Tcl_LinkVar(interp, var59, (char *) &buttons_menu, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var60, (char *) &min_transmit_altitude, TCL_LINK_INT);
+  Tcl_LinkVar(interp, var61, (char *) &parallels_angle, TCL_LINK_DOUBLE);
+  Tcl_LinkVar(interp, var62, (char *) &equatorial_exclusion_angle, TCL_LINK_DOUBLE);
 
   /* execute initialization */
   {
