@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -19,7 +19,7 @@
 ######################################################
 #
 # about.tcl
-# $Id: about.tcl,v 1.27 2013/05/05 05:19:25 lloydwood Exp $
+# $Id: about.tcl,v 1.33 2016/01/09 04:21:17 lloydwood Exp $
 
 proc about(build) {} {
     if {[eval window(raise) about]} return
@@ -40,34 +40,29 @@ proc about(build) {} {
     $logo create image 75 0 -image graphic -anchor n
     pack $logo
 
-    build_Label $cmd l1 "Satellite Constellation Simulation and Visualization"
+    build_Label $cmd l1 "Satellite constellation simulation and Visualization"
     $cmd.l1.label configure -font *-times-medium-i-normal--*-140-*-*-*-*-*-* \
 	-fg blue
     pack $cmd.l1 -anchor n -ipadx 15m -ipady 2m
 
     build_Label $cmd l2 \
-"A user manual is in SaVi's manual/ directory.
+"http://savi.sourceforge.net/
+A user manual is in SaVi's manual/ directory.
 
 
 Originally created at The Geometry Center
 by Patrick Worfolk and Robert Thurman.
 
-Interval decay showing coverage movement
-contributed by Gregory LaCoste.
-
 Enhanced and maintained by Lloyd Wood.
-http://info.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
-http://savi.sourceforge.net/
-
+http://personal.ee.surrey.ac.uk/Personal/L.Wood/software/SaVi/
 
 SaVi is free software. You may redistribute SaVi and/or modify
 SaVi only under the terms that are given in the file COPYRIGHT,
 which you should have received along with your copy of SaVi.
 
+Copyright (c) 2001-2016 by Lloyd Wood.
 Copyright (c) 1995-1997 by The Geometry Center
-http://www.geom.uiuc.edu/locate/SaVi
-
-Also Copyright (c) 2001-2013 by Lloyd Wood.
+http://www.geom.uiuc.edu/~worfolk/SaVi/
 
 [satellites VERSION]
 
