@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # coverage.tcl
 #
-# $Id: coverage.tcl,v 1.143 2013/05/05 05:19:25 lloydwood Exp $
+# $Id: coverage.tcl,v 1.166 2016/01/09 04:21:17 lloydwood Exp $
 
 # Note: IM_W and IM_H are linked to C variables for the image size
 
@@ -42,6 +42,7 @@ proc coverage(init) {} {
     set project_tracks_flag 0
     set coverage_proj_flag 0
     set coverage_angle_flag 0
+    set coverage_flag 0
 
     set NUM_COLORS_PREV 0
 
@@ -53,13 +54,15 @@ proc coverage(init) {} {
     set tracks_flag_dismissed 1
 
     # this and popup menu match master list in globals.h
-    set Projection(unprojected) 0
-    set Projection(cylindrical) 1
-    set Projection(sinusoidal) 2
-    set Projection(sinusoidal_90) 3
-    set Projection(spherical) 4
-    set Projection(spherical_90) 5
+    set Projection(unprojected_mask) 0
+    set Projection(unprojected) 1
+    set Projection(cylindrical) 2
+    set Projection(sinusoidal) 3
+    set Projection(sinusoidal_90) 4
+    set Projection(spherical) 5
+    set Projection(spherical_90) 6
 
+    set coverage_projection $Projection(unprojected)
     set last_coverage_projection $coverage_projection
 }
 
@@ -68,7 +71,7 @@ proc coverage(build) {} {
 	coverage_proj_flag coverage_angle_flag project_tracks_flag map_flag \
 	coverage_projection coverage_angle IM_W IM_H im_x_offset im_y_offset \
 	coverage_flag_dismissed tracks_flag_dismissed no_access_flag_dismissed \
-	coverage_display_center_longitude coverage_name geomview_module \
+	coverage_display_center_longitude coverage_name \
 	sun_flag Fisheye NUM_COLORS NUM_COLORS_PREV
 
 
@@ -76,12 +79,8 @@ proc coverage(build) {} {
 	coverage_size(build)
 	return
     }
-
-    if [winfo exists .coverage] {
-	wm deiconify .coverage
-	raise .coverage
-	return
-    }
+    
+    if {[eval window(raise) coverage]} return
 
     set coverage_name [build_Toplevel coverage]
 
@@ -132,7 +131,7 @@ proc coverage(build) {} {
 	     {"Reverse shading" "coverage(reverse_colors)"} \
 	     {} \
              {"Select random colors" "coverage(random_colors)"} \
-	     {"Swap diversity and decay colors" "coverage(swap_color_diversity_decay)"} \
+	     {"Swap color swatches" "coverage(swap_color_diversity_decay)"} \
 	     {"Shade between end colors" "coverage(blend_colors)"} \
 	     {} \
 	     {"SaVi color shades" "coverage(restore_colors)"} }
@@ -176,16 +175,21 @@ proc coverage(build) {} {
     bind $c <Button-1> {coverage(lat_long) %x %y}
     bind $c <Control-Button-1> {coverage_set(lat_long) %x %y}
 
+    bind $c <Button-2> {coverage(back_step)}
+    bind $c <Button-3> {coverage(forw_step)}
+    bind $c <Shift-Button-2> {coverage(backwards)}
+    bind $c <Shift-Button-3> {coverage(forwards)}
+
     set cmdq [build_StdFrame $cmd q]
     build_Optionslist $cmdq olist \
 	{"Show Earth map" map_flag}
     pack $cmdq.olist -side left
     build_IPopupMenu $cmdq p0 "projected as:" \
-        coverage_projection coverage(map) {"unprojected" "cylindrical" "sinusoidal" "sinusoidal (90W)" "spherical" "spherical (90W)"}
+        coverage_projection coverage(map) {"unprojected land/sea" "unprojected" "cylindrical" "sinusoidal" "sinusoidal (90W)" "spherical" "spherical (90W)"}
     pack $cmdq.p0 -side left
 
     build_LabelEntryColumns $cmdq p1 \
-	{text "" {"Clicked coordinates: "}} \
+	{text "" {"Clicked: "}} \
 	{label "" {Fisheye(clicked_coords)}}
 
     pack $cmdq.p1 -side left
@@ -274,7 +278,7 @@ proc coverage(build) {} {
 
     # handles window being closed and reopened when sunlight on
     if {$sun_flag} {
-	coverage(sunlight_labels_on)
+	coverage(labels_show_sunlight)
     }
 
     build_LabelEntryColumns $cmd le2 \
@@ -427,16 +431,24 @@ proc coverage(set_angle) v {
 }
 
 proc coverage(update_angle) {} {
-    global coverage_flag
+    global coverage_flag coverage_angle cones_flag footprints_flag
 
+    set coverage_angle [expr abs($coverage_angle)]
+    if {$coverage_angle > 90} {
+	set coverage_angle 90
+    }
+    
     coverage(update_decay)
 
-    set flag $coverage_flag
-    set coverage_flag 1
-    if {$flag == 0} {
-      set coverage_flag 0
+    if {$coverage_flag == 1} {
+	set coverage_flag 0
+	set coverage_flag 1
     }
 
+    coverage(update)
+
+    geomview(update_cones_footprints)
+
     fisheye(update)
 }
 
@@ -510,25 +522,72 @@ proc coverage(init_coldiv_coldec) {} {
     set COLDEC(19) #ffffff
 }
 
-proc coverage(sunlight_labels_off) {} {
-global NUM_COLORS
+proc coverage(labels_show_land_sea) {} {
+    global NUM_COLORS coverage_projection Projection
+
+    if {$coverage_projection != $Projection(unprojected_mask)} {
+	return
+    }
 
     if [winfo exists .coverage] {
-	set last [expr $NUM_COLORS - 1]
+	set last [expr $NUM_COLORS]
+	for {set i 1} {$i < $last} {incr i} {
+	    set j [expr $i-1]
+	    .coverage.cmd.a.ce.cf.$i configure -text $j
+	    .coverage.cmd.a.ce.cg.$i configure -text $j
+	}
+	
+	set j [expr $last - 1]
+	.coverage.cmd.a.ce.cf.$NUM_COLORS configure -text "$j+"
+	.coverage.cmd.a.ce.cg.$NUM_COLORS configure -text "$j+"
+	.coverage.cmd.a.ce.cf.0 configure -text "satellites in view\n(coverage on land)"
+	.coverage.cmd.a.ce.cg.0 configure -text "satellites in view\n(coverage on sea)"
+    }
+}
+
+proc coverage(labels_show_diversity) {} {
+    #top line only
+    global NUM_COLORS coverage_projection Projection
+
+    if {$coverage_projection == $Projection(unprojected_mask)} {
+	return
+    }
+
+    if [winfo exists .coverage] {
+	set last [expr $NUM_COLORS ]
+	for {set i 1} {$i < $last} {incr i} {
+	    .coverage.cmd.a.ce.cf.$i configure -text $i
+	}
+	
+	.coverage.cmd.a.ce.cf.$NUM_COLORS configure -text "$NUM_COLORS+"
+	.coverage.cmd.a.ce.cf.0 configure -text "satellites in view\n(coverage diversity)"
+    }
+}
+
+proc coverage(labels_show_decay) {} {
+    global NUM_COLORS coverage_projection Projection
+
+    if {$coverage_projection == $Projection(unprojected_mask)} {
+	return
+    }
+
+    if [winfo exists .coverage] {
+	set last [expr $NUM_COLORS]
 	for {set i 1} {$i < $last} {incr i} {
 	    .coverage.cmd.a.ce.cg.$i configure -text $i
 	}
 
-	if {$last > 0 } {
-	    .coverage.cmd.a.ce.cg.$last configure -text "$last"
-	}
 	.coverage.cmd.a.ce.cg.$NUM_COLORS configure -text "$NUM_COLORS+"
 	.coverage.cmd.a.ce.cg.0 configure -text "intervals since view\n(coverage decay)"
     }
 }
 
-proc coverage(sunlight_labels_on) {} {
-global NUM_COLORS
+proc coverage(labels_show_sunlight) {} {
+    global NUM_COLORS coverage_projection Projection
+
+    if {$coverage_projection == $Projection(unprojected_mask)} {
+	return
+    }
 
     if [winfo exists .coverage] {
 	set last [expr $NUM_COLORS - 1]
@@ -546,10 +605,16 @@ global NUM_COLORS
 
 
 proc coverage(update_wells) {} {
-global COLDIV COLDEC NUM_COLORS
-global COLOR coverage_flag no_access_flag sun_flag
+global COLDIV COLDEC NUM_COLORS COLOR
+global coverage_projection Projection coverage_flag no_access_flag sun_flag
 
-    if {$sun_flag == 1} {
+    if {$coverage_projection == $Projection(unprojected_mask)} {
+	if {$no_access_flag == 0} {
+	    set j 2
+	} else {
+	    set j 0
+	}
+    } elseif {$sun_flag == 1} {
 	set j [expr $NUM_COLORS - 1]
     } else {
 	set j 0
@@ -573,17 +638,16 @@ global COLOR coverage_flag no_access_flag sun_flag
 	      -command "coverage(diversitycolor) $i"
 	}
 
-
-	if {($no_access_flag == 1) && ($i >= $j)} {
+	if {($coverage_flag == 0) || (($no_access_flag == 0)&&($coverage_projection != $Projection(unprojected_mask))) || ($i < $j)} {
+	  .coverage.cmd.a.ce.cg.$i configure -bg $COLOR(bg) \
+	       -activebackground $COLOR(bg) -highlightbackground black \
+	       -relief flat \
+	       -command ""
+	} else {
 	   .coverage.cmd.a.ce.cg.$i configure -bg $COLDEC($i) \
 	       -activebackground $COLDEC($i) -highlightbackground $COLDEC($i) \
 	       -relief groove \
 	       -command "coverage(decaycolor) $i"
-	} else {
-	   .coverage.cmd.a.ce.cg.$i configure -bg $COLOR(bg) \
-	       -activebackground $COLOR(bg) -highlightbackground black \
-	       -relief flat \
-	       -command ""
 	}
     }
 }
@@ -597,6 +661,10 @@ proc coverage(update_colors) {} {
 	set COLDEC($i) [eval format "#%06x" $DEC($i)]
     }
     satellites COLOR_UPDATE
+
+    # if texturemapping, need to update sphere map
+    geomview(update_texture)
+
     coverage(update_wells)
     coverage(update)
 }
@@ -614,7 +682,7 @@ proc coverage(swap_color_diversity_decay) {} {
 }
 
 proc coverage(random_color_values) {} {
-    global DIV DEC
+    global DIV DEC coverage_projection Projection
     global NUM_COLORS
 
     global coverage_flag no_access_flag sun_flag
@@ -623,7 +691,7 @@ proc coverage(random_color_values) {} {
 	if {$coverage_flag == 1} {
 	    set DIV($i) [random_color]
 	}
-	if {($no_access_flag == 1) && ($sun_flag == 0)} {
+	if {(($coverage_projection == $Projection(unprojected_mask)) || ($no_access_flag == 1)) && ($sun_flag == 0)} {
 	    set DEC($i) [random_color]
 	}
     }
@@ -833,10 +901,11 @@ proc coverage(diversitycolor) {n} {
 }
 
 proc coverage(decaycolor) {n} {
-    global DEC
+    global DEC coverage_projection Projection
     global COLDEC no_access_flag
 
-    if {$no_access_flag == 0} return
+    if {($coverage_projection != $Projection(unprojected_mask)) &&
+	($no_access_flag == 0)} return
 
     if {$n == "1"} {
 	set s ""
@@ -959,7 +1028,7 @@ proc coverage(lat_long) {x y} {
 	    set y 1
 	}
 	set lat [expr asin($y)/$PI*180.0]
-    } elseif {$coverage_projection == $Projection(unprojected)} {
+    } elseif {($coverage_projection == $Projection(unprojected))||($coverage_projection == $Projection(unprojected_mask))} {
 	# unprojected
 	set long [expr (($x%$IM_W)-$HALF_X)/double($IM_W)*360.0+$Longitude_Center_Line]
 	set y [expr 1-$y/double($IM_H)*2]
@@ -1116,7 +1185,7 @@ proc coverage_set(lat_long) {x y} {
 }
 
 proc coverage(foot) {} {
-    global coverage_angle
+    global coverage_angle coverage_flag
 
     if {$coverage_angle > 90} {
       set coverage_angle 90
@@ -1134,6 +1203,8 @@ proc coverage(title) {} {
 	build_Title $coverage_name "view of coverage on cylindrical Earth map"
     } elseif {$coverage_projection == $Projection(unprojected)} {
 	build_Title $coverage_name "view of coverage on unprojected (equirectangular) Earth map"
+    } elseif {$coverage_projection == $Projection(unprojected_mask)} {
+	build_Title $coverage_name "view of coverage on unprojected (equirectangular) colorful Earth map"
     } elseif {$coverage_projection == $Projection(sinusoidal)} {
 	build_Title $coverage_name "view of coverage on sinusoidal Earth map"
     } elseif {$coverage_projection == $Projection(sinusoidal_90)} {
@@ -1147,7 +1218,7 @@ proc coverage(title) {} {
 
 proc coverage(map) {} {
     global coverage_proj_flag coverage_projection last_coverage_projection \
-	geomview_module Projection
+	Projection sun_flag
 
     if {$coverage_projection == $last_coverage_projection} return
 
@@ -1155,13 +1226,23 @@ proc coverage(map) {} {
 
     set coverage_proj_flag [expr 1 - $coverage_proj_flag]
 
-    # this is a hack to reset Earth while dynamic texturemapping if changed
-    # from cylindrical projection.
-    if {$geomview_module == 1} {
-	geomview(reset_texture)
+    if {($coverage_projection == $Projection(unprojected_mask))} {
+	coverage(labels_show_land_sea)
+    } else {
+	if {$sun_flag} {
+	    coverage(labels_show_diversity)
+	    coverage(labels_show_sunlight)
+	} else {
+	    coverage(labels_show_diversity)
+	    coverage(labels_show_decay)
+	}
     }
 
     set last_coverage_projection $coverage_projection
-
     coverage(update)
+
+        # this is a hack to reset Earth while dynamic texturemapping,
+    # if we move from cylindrical/unprojected projections supporting
+    # texturemapping to other projections that don't.
+    geomview(update_texture)
 }
