@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # fisheye.tcl
 #
-# $Id: fisheye.tcl,v 1.55 2013/05/05 05:19:26 lloydwood Exp $
+# $Id: fisheye.tcl,v 1.65 2016/01/09 04:21:17 lloydwood Exp $
 
 proc fisheye(init) {} {
     global fisheye_flag fisheye_reverse_view_flag fisheye_names_flag fisheye_numbers_flag \
@@ -56,8 +56,9 @@ proc fisheye(init) {} {
 }
 
 proc fisheye(build) {} {
-    global fisheye_flag fisheye_flag_dismissed fisheye_names_flag fisheye_times_flag \
-    fisheye_numbers_flag fisheye_viewpoint_flag Fisheye
+    global Fisheye fisheye_flag fisheye_flag_dismissed fisheye_names_flag
+    global fisheye_times_flag fisheye_numbers_flag fisheye_viewpoint_flag
+    global plane_flag parallels_angle
 
     if {[eval window(raise) fisheye]} return
 
@@ -116,6 +117,7 @@ proc fisheye(build) {} {
 	     {"Beijing, China" "fisheye(set_location) 39 55 116 25 {Beijing, China}"} \
 	     {"Berlin, Germany" "fisheye(set_location) 52 30 13 25 {Berlin, Germany}"} \
 	     {"Bombay, India" "fisheye(set_location) 19 0 72 48 {Bombay, India}"} \
+             {"Brisbane, Australia" "fisheye(set_location) -27 28 153 0 {Brisbane, Australia}"} \
 	     {"Brussels, Belgium" "fisheye(set_location) 50 52 4 22 {Brussels, Belgium}"} \
 	     {"Buenos Aires, Argentina" "fisheye(set_location) -34 35 -58 22 {Buenos Aires, Argentina}"} \
 	     {"Canberra, Australia" "fisheye(set_location) -35 18 149 7 {Canberra, Australia}"} \
@@ -127,6 +129,7 @@ proc fisheye(build) {} {
 	     {"Madrid, Spain" "fisheye(set_location) 40 26 -3 42 {Madrid, Spain}"} \
 	     {"Mecca, Saudi Arabia" "fisheye(set_location) 21 29 39 45 {Mecca, Saudi Arabia}"} \
 	     {"Melbourne, Australia" "fisheye(set_location) -37 47 144 58 {Melbourne, Australia}"} \
+             {"Miami, Florida" "fisheye(set_location) 25 47 -80 13 {Miami, Florida}"} \
 	     {"Moscow, Russia" "fisheye(set_location) 55 45 37 36 {Moscow, Russia}"} \
 	     {"New York, USA" "fisheye(set_location) 40 47 -73 58 {New York, USA}"} \
 	     {"Oslo, Norway" "fisheye(set_location) 59 57 10 42 {Oslo, Norway}"} \
@@ -156,12 +159,19 @@ proc fisheye(build) {} {
 	{"Show time in view" fisheye_times_flag} \
 	{"Plot location on map" fisheye_viewpoint_flag} \
 	{} \
+ 	{"Show equator" plane_flag} \
+	{} \
 	{"Reverse fisheye view" fisheye_reverse_view_flag}
 
     set cmd [build_CmdFrame $fisheye_name cmd]
 
     set p "$cmd.p"
-    canvas $p -bg black -height 300 -width 300
+    canvas $p -bg black -height 360 -width 360
+
+    bind $p <Button-2> {main(back_step)}
+    bind $p <Button-3> {main(forw_step)}
+    bind $p <Shift-Button-2> {main(backwards)}
+    bind $p <Shift-Button-3> {main(forwards)}
 
     pack $p -side right
     pack $p -fill both -expand 1
@@ -169,7 +179,7 @@ proc fisheye(build) {} {
     set cmdr [build_StdFrame $cmd r]
 
     build_LabelEntryColumns $cmdr le1 \
-        {label "" {time Fisheye(location_name) fisheye_lat_lon}}
+	{label "" {time Fisheye(location_name) fisheye_lat_lon}}
 
     pack $cmdr
 
@@ -177,17 +187,28 @@ proc fisheye(build) {} {
 	{"Show numbers" fisheye_numbers_flag} \
 	{"Show names" fisheye_names_flag} \
 	{"Show time in view" fisheye_times_flag} \
-	{"Plot location on map" fisheye_viewpoint_flag}
+	{"Plot location on map" fisheye_viewpoint_flag} \
+	{"Show equator" plane_flag}
 
     set cmdb [build_StdFrame $cmd b]
+
     build_LabelEntryColumns $cmdb le2 \
-	{text "coverage angle" ""} \
-	{dentry "" {coverage_angle}}
+        {text "" "Parallels"} \
+        {dentry "" {parallels_angle}} \
+	{text "" "degrees"}
 
-    pack $cmdb
 
-    bind $cmdb.le2.c1.0 <Return> coverage(foot)
-    bind $cmdb.le2.c1.0 <Tab> coverage(foot)
+    build_LabelEntryColumns $cmdb le3 \
+        {text "" "Coverage"} \
+        {dentry "" {coverage_angle}} \
+	{text "" "degrees"}
+
+    bind $cmdb.le2.c1.0 <Return> equator(update_angle)
+    bind $cmdb.le2.c1.0 <Tab> equator(update_angle)
+    bind $cmdb.le3.c1.0 <Return> coverage(update_angle)
+    bind $cmdb.le3.c1.0 <Tab> coverage(update_angle)
+
+    pack $cmdb -fill both -expand 1
 
     set cmdq [build_StdFrame $cmd q]
 
@@ -346,6 +367,7 @@ proc fisheye(delete) {} {
 	$p delete crosses
 	$p delete labels
 	$p delete mask_elevation
+	$p delete equator
     }
 }
 
