@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,12 +20,12 @@
 #
 # init.tcl
 #
-# $Id: init.tcl,v 1.80 2013/05/05 05:19:26 lloydwood Exp $
+# $Id: init.tcl,v 1.91 2016/01/09 04:21:17 lloydwood Exp $
 
 proc geomview_init {} {
     global satellites_flag box_sat_flag planes_sat_flag fancy_sat_flag \
 	   sphere_sat_flag fast_marker_sat_flag cones_flag footprints_flag \
-	   orbits_flag axes_flag plane_flag stars_flag \
+	   orbits_flag axes_flag stars_flag \
 	   earth_flag simple_earth_flag fancy_earth_flag texture_flag \
 	   geomview_flag geomview_dynamic_texture_flag COLOR
 
@@ -45,7 +45,6 @@ proc geomview_init {} {
     trace variable cones_flag w flag_change
 
     trace variable axes_flag w flag_change
-    trace variable plane_flag w flag_change
     trace variable stars_flag w flag_change
 
     trace variable earth_flag w flag_change
@@ -57,7 +56,7 @@ proc geomview_init {} {
 
     trace variable geomview_flag w flag_change
 
-        set satellites_flag 1
+    set satellites_flag 1
     set fast_marker_sat_flag 1
     set box_sat_flag 0
     set planes_sat_flag 0
@@ -69,11 +68,10 @@ proc geomview_init {} {
     set cones_flag 0
 
     set axes_flag 1
-    set plane_flag 0
     set stars_flag 0
 
     set earth_flag 1
-    set simple_earth_flag 0
+    set simple_earth_flag 1
     set fancy_earth_flag 0
     set texture_flag 1
 
@@ -88,6 +86,7 @@ proc app_init {} {
     global first_filename last_filename source_comments comments_text comments_file details_source
     global helpfile_text helpfile_name geomview_module
     global realtime_flag sun_flag playbar delta_t splash_about rendering_size
+    global plane_flag
     global modifier modifier_indicator
 
     # env is unused.
@@ -169,18 +168,22 @@ proc app_init {} {
     set source_comments ""
     set details_source ""
 
+    trace variable plane_flag w flag_change
+    set plane_flag 0
+
     set sun_flag 0
     trace variable sun_flag w flag_change
 
     trace variable realtime_flag w flag_change
     set realtime_flag 0
 
-    coverage(init)
-    fisheye(init)
-
     # load in fake sun as first satellite (zero)
     sunlight(create)
 
+    equator(init)
+    coverage(init)
+    fisheye(init)
+
     # build top window
     set last_filename ""
     main(build)
@@ -189,7 +192,7 @@ proc app_init {} {
 proc flag_change {name element op} {
     global geomview_module box_sat_flag planes_sat_flag fancy_sat_flag \
            sphere_sat_flag satellites_flag no_access_flag sun_flag \
-	   simple_earth_flag fancy_earth_flag
+	   simple_earth_flag fancy_earth_flag plane_flag
     upvar #0 $name flag
 
    if {$geomview_module == 1} {
@@ -244,8 +247,6 @@ proc flag_change {name element op} {
 	if {$flag == 1} {satellites CONES_ON} else {satellites CONES_OFF}
     } elseif {$name == "axes_flag"} {
 	if {$flag == 1} {satellites AXES_ON} else {satellites AXES_OFF}
-    } elseif {$name == "plane_flag"} {
-	if {$flag == 1} {satellites PLANE 0.0 0.0} else {satellites PLANE_OFF}
     } elseif {$name == "stars_flag"} {
 	if {$flag == 1} {satellites STARS_ON} else {satellites STARS_OFF}
     } elseif {$name == "earth_flag"} {
@@ -280,7 +281,7 @@ proc flag_change {name element op} {
 	if {$flag == 1} {satellites REALTIME_ON} else {satellites REALTIME_OFF}
     } elseif {$name == "coverage_flag"} {
 	if {$flag == 1} {satellites COVERAGE_ON} else {satellites COVERAGE_OFF}
-	if [winfo exists .coverage] coverage(update_wells)
+	if {[winfo exists .coverage]} coverage(update_wells)
     } elseif {$name == "no_access_flag"} {
 	if {$flag == 1} { satellites NO_ACCESS_ON
 	} else {
@@ -289,7 +290,7 @@ proc flag_change {name element op} {
 	    }
 	    satellites NO_ACCESS_OFF
 	}
-	if [winfo exists .coverage] coverage(update_wells)
+	if {[winfo exists .coverage]} coverage(update_wells)
     } elseif {$name == "print_access_flag"} {
 	if {$flag == 1} {satellites PRINT_ACCESS_ON} else {satellites PRINT_ACCESS_OFF}
     } elseif {$name == "map_flag"} {
@@ -298,6 +299,16 @@ proc flag_change {name element op} {
 	} else {
 	    satellites MAP_OFF
 	}
+    } elseif {$name == "plane_flag"} {
+        if {$flag == 1} {
+            satellites PLANE 0.0 0.0
+	    equator(create)
+            fisheye(update)
+        } else {
+            satellites PLANE_OFF
+            fisheye(update)
+        }
+
     } elseif {$name == "fisheye_reverse_view_flag"} {
 	if {$flag == 1} {satellites FISHEYE_REVERSE_VIEW_ON} else {satellites FISHEYE_REVERSE_VIEW_OFF}
     } elseif {$name == "fisheye_print_inview_flag"} {
@@ -327,12 +338,12 @@ proc flag_change {name element op} {
 	    satellites SUN_ON
 	    set no_access_flag 1
 	    main(show_sunlight)
-	    coverage(sunlight_labels_on)
+	    coverage(labels_show_sunlight)
 	    coverage(update)
 	} else {
 	    satellites SUN_OFF
 	    main(hide_sunlight)
-	    coverage(sunlight_labels_off)
+	    coverage(labels_show_decay)
 	    coverage(update_decay)
 	}
     } else {
