@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # main.tcl
 #
-# $Id: main.tcl,v 1.146 2013/05/05 05:37:01 lloydwood Exp $
+# $Id: main.tcl,v 1.158 2016/01/17 23:24:21 lloydwood Exp $
 
 proc main(build) {} {
     global main_name COLOR FONT TITLE geomview_module last_filename PLATFORM
@@ -112,7 +112,7 @@ proc main(build) {} {
     }
 
     label $cmd.l -text \
-	"no.  semi-major axis      eccentricity     inclination   longitude asc. node     arg. periapsis     time to periapsis  satellite name" \
+	"no.  semi-major axis  eccentricity  inclination  longitude asc. node  arg. periapsis  time to periapsis  satellite name" \
 	-font $FONT(label)
     listbox $cmd.lb -yscrollcommand "$cmd.scroll set" \
 	-height 2 -width $WIDTH -selectmode single \
@@ -127,6 +127,8 @@ proc main(build) {} {
     bind $cmd.lb <Shift-Double-Button-1> {main(rangedblselect) [%W nearest %y]}
     bind $cmd.lb <Control-Button-1> {main(itemselect) [%W nearest %y]}
     bind $cmd.lb <Control-Double-Button-1> {main(itemdblselect) [%W nearest %y]}
+    bind $cmd.lb <Delete> {main(delete)}
+    bind $cmd.lb <Insert> {main(new)}
     scrollbar $cmd.scroll -command "$cmd.lb yview"
     pack $cmd.scroll -side right -fill y
 
@@ -211,6 +213,9 @@ proc main(constellations_menu) {submenu} {
         {"Orblink" "main(constellation) orblink.tcl"} \
         {"LEq0" "main(constellation) leqo.tcl"} \
         {} \
+	{"LeoSat (108)" "main(constellation) leosat.tcl"} \
+	{"OneWeb (720)" "main(constellation) oneweb.tcl"} \
+	{} \
 	{"COMMstellation (78)" "main(constellation) commstellation-78.tcl"} \
 	{"NeLS (120)" "main(constellation) nels.tcl"} \
 	{"Celestri (63)" "main(constellation) celestri.tcl"} \
@@ -355,6 +360,8 @@ proc main(exit) {} {
     }
 
     satellites EXIT
+
+    puts stderr "\nSaVi: thankyou for using SaVi.\n"
     exit
 }
 
@@ -628,6 +635,7 @@ proc main(delete_all) {} {
 
     main(reset_title)
 
+    geomview(update_texture)
     coverage(update_decay)
     main(update)
 }
@@ -652,8 +660,10 @@ proc main(constellation) {filename} {
 
 proc main(source_file) {filename} {
     global coverage_angle coverage_angle_flag PI params source_comments details_source
+    global min_transmit_altitude
 
     set coverage_angle_old $coverage_angle
+    set min_transmit_altitude_old $min_transmit_altitude
 
     # interpret as a tcl file. Set up constants.
     set MU $params(Mu)
@@ -689,13 +699,18 @@ proc main(source_file) {filename} {
     set details_source "$filename"
 
     puts stderr "\nSaVi: loaded $filename"
+
+    if {$min_transmit_altitude != $min_transmit_altitude_old} {
+        puts stderr "      changed minimum transmit altitude from $min_transmit_altitude_old to $min_transmit_altitude km."
+    }
     if {$coverage_angle != $coverage_angle_old} {
-	puts stderr "      changed coverage angle from $coverage_angle_old to $coverage_angle."
+	puts stderr "      changed coverage angle from $coverage_angle_old to $coverage_angle degrees."
 	if {$coverage_angle_flag} {
 	    puts stderr "      Coverage angle probably describes mask elevation."
 	}
     }
 
+    geomview(update_texture)
     details(rebuild)
 }
 
@@ -725,6 +740,7 @@ proc main(load_file) {filename} {
     }
 
     if {$geomview_module == 1} {
+	geomview(update_texture)
         satellites GV_SEND "(ui-freeze off)"
     }
 
