@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2013 by Lloyd Wood.
+#  Also Copyright (c) 2016 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,10 +20,10 @@
 #
 # utils.tcl
 #
-# $Id: utils.tcl,v 1.54 2013/05/05 05:19:26 lloydwood Exp $
+# $Id: utils.tcl,v 1.60 2016/01/09 04:21:17 lloydwood Exp $
 
 proc window(raise) {window} {
-    if [winfo exists .$window] {
+    if {[winfo exists .$window]} {
 	wm deiconify .$window
 	raise .$window
 	return 1
@@ -102,7 +102,7 @@ proc string_ends {filename extension} {
 #
 # Returns: .name
 #
-proc build_Wname name {
+proc build_Wname {name} {
     return .$name
 }
 
@@ -194,7 +194,7 @@ proc build_Menubar {parent name helpmenu args} {
     }
 
     # menubars are not currently rebuilt!
-    if [winfo exists $mbarname.b0] {
+    if {[winfo exists $mbarname.b0]} {
 	puts stderr "\nbuild_Menubar: NOT rebuilding $mbarname"
 	return
     }
@@ -216,20 +216,20 @@ proc build_Menubar {parent name helpmenu args} {
         #add other menubuttons on left side
         set i 0 ; set menubuttons {}
         foreach arg $args {
-	          if {[llength $arg] > 0} {
+	     if {[llength $arg] > 0} {
                 # hack to show all text cut short by popup indicator
                 # two spaces for long words
                 set menuname [lindex $arg 0]
                 set menuname "$menuname  "
 
-	              menubutton $mbarname.b$i -text $menuname \
-		                       -menu $mbarname.b$i.menu -font $FONT(button)
-	              lappend menubuttons $mbarname.b$i
-	              if {[llength $arg] > 1} {
+                menubutton $mbarname.b$i -text $menuname \
+		           -menu $mbarname.b$i.menu -font $FONT(button)
+	        lappend menubuttons $mbarname.b$i
+	        if {[llength $arg] > 1} {
                     eval build_Menu $mbarname.b$i [lrange $arg 1 end]
                 }
-	              incr i
-	          }
+	        incr i
+	     }
         }
         if {[llength $menubuttons] > 0} {
 	          eval pack $menubuttons -side left
@@ -259,7 +259,7 @@ proc build_Menubar {parent name helpmenu args} {
 	$mbarname add cascade -menu $mbarname.helpx -label [lindex $helpmenu 0] \
 	    -font $FONT(button)
 	eval build_Menu $mbarname.helpx [lrange $helpmenu 1 end]
-     }
+    }
 
     # display menubar across the top of the panel
     $parent configure -menu $mbarname
@@ -576,8 +576,8 @@ proc build_IPopupMenu { parent name label ivar command items } {
     if {![llength $items]} {
 	if {[winfo exists $wname.mb]} {destroy $wname.mb}
 	pack $wname.label -side left -padx 0.1c
-	pack $wname -fill x
-	return $wname -pady 0.1c
+	pack $wname -fill x -pady 0.1c
+	return $wname
     }
 
     # make menubutton
@@ -770,7 +770,7 @@ proc build_LabelEntryColumns {parent name args } {
 	    puts stderr "\nunknown widget name: $_type"
 	}
 
-	if $valid_type {
+	if {$valid_type} {
 	    # create column and header
 	    set obj $parent.$name.$_code
 	    if { ![winfo exists $obj] } {
@@ -778,14 +778,14 @@ proc build_LabelEntryColumns {parent name args } {
 		pack $obj -fill x -side left
 		# -padx 2 -pady 1
 	    }
-	    if [string length "$_head"] {
+	    if {[string length "$_head"]} {
 		if { ![winfo exists $obj.head] } {
 		    label $obj.head -anchor n -font $FONT(label)
 		    pack $obj.head -side top -padx 2 -pady 1
 		}
 		$obj.head configure -text "$_head"
 	    } else {
-		if [winfo exists $obj.head] {
+		if {[winfo exists $obj.head]} {
 		    destroy $obj.head
 		}
 	    }
@@ -794,7 +794,7 @@ proc build_LabelEntryColumns {parent name args } {
 	    set _n 0
 	    foreach l $_list {
 		set obj_n $obj.$_n
-		if { ![winfo exists $obj_n] } {
+		if {![winfo exists $obj_n]} {
 		    eval $col_entry
 		    pack $obj_n -side top -padx 0.1c -pady $pady -fill x
 		}
@@ -838,7 +838,7 @@ proc build_Label {parent name message} {
     set fname [build_StdFrame $parent $name]
     if {[winfo exists $fname.label]} {
         $fname.label configure -text $message
-    } {
+    } else {
       label $fname.label -text $message -font $FONT(label)
       pack $fname.label -expand 1 -fill both
     }
@@ -864,7 +864,9 @@ proc build_options_menu {owner args} {
     }
 
     # create menu
-    if [winfo exists $owner] {destroy $owner}
+    if {[winfo exists $owner]} {
+	destroy $owner
+    }
     if {$buttons_menu == 1} {
         menu $owner -font $FONT(label)
     } else {
@@ -901,7 +903,7 @@ proc longest list {
 #
 proc loadfile_into_text {textw filename} {
     set ok 0
-    if [file exists "$filename"] {
+    if {[file exists "$filename"]} {
 	set f [open "$filename"]
 	while {![eof $f]} {
 	    $textw insert end [read $f 1000]
